@@ -96,7 +96,7 @@ NULL
 
 #' @rdname load_balance
 #' @export
-balance.info <- function(X.gbd, comm = .pbd_env$.SPMD.CT$comm,
+balance.info <- function(X.gbd, comm = .pbd_env$SPMD.CT$comm,
     gbd.major = .pbd_env$gbd.major, method = .pbd_env$divide.method[1]){
   COMM.SIZE <- comm.size(comm)
   COMM.RANK <- comm.rank(comm)
