@@ -1,4 +1,4 @@
-library(pbdDEMO, quiet=T)
+library(pbdDEMO, quietly=TRUE)
 
 init.grid()
 
@@ -6,7 +6,7 @@ init.grid()
 n <- 1e4
 p <- 250
 
-comm.set.seed(diff=T)
+comm.set.seed(1234, diff=T)
 dx <- ddmatrix("rnorm", nrow=n, ncol=p, bldim=c(4,4), mean=100, sd=25)
 
 # PCA with scaling, retaining only 90% of the variation
